SWDEV-470698 - fix formatting, add format check workflow (#657)

이 커밋은 다음에 포함됨:
Danylo Lytovchenko
2025-08-20 16:28:06 +02:00
커밋한 사람 GitHub
부모 5840940caa
커밋 f7338717ae
1574개의 변경된 파일162972개의 추가작업 그리고 199346개의 파일을 삭제
+4 -4
파일 보기
@@ -26,14 +26,14 @@ static void Copy_to_device() {
int* A_h = nullptr;
int* A_d = nullptr;
HIP_CHECK(hipHostMalloc(&A_h, ele_size*sizeof(int)));
HIP_CHECK(hipHostMalloc(&A_h, ele_size * sizeof(int)));
HIP_CHECK(hipMalloc(&A_d, ele_size * sizeof(int)));
for (unsigned int i = 0; i < ele_size; ++i) {
A_h[i] = 123;
}
HIP_CHECK(hipMemcpyAsync(A_d, A_h, ele_size * sizeof(int), hipMemcpyHostToDevice,
hipStreamPerThread));
HIP_CHECK(
hipMemcpyAsync(A_d, A_h, ele_size * sizeof(int), hipMemcpyHostToDevice, hipStreamPerThread));
// Clean up
HIP_CHECK(hipHostFree(A_h));
HIP_CHECK(hipFree(A_d));
@@ -48,7 +48,7 @@ TEST_CASE("Unit_hipStreamPerThread_MultiThread") {
constexpr unsigned int MAX_THREAD_CNT = 10;
std::vector<std::thread> threads(MAX_THREAD_CNT);
for (auto &th : threads) {
for (auto& th : threads) {
th = std::thread(Copy_to_device);
}